GEOWATCH Docs
-------------

This is the entry point for GEOWATCH documentation. There is a combination of
internal SMART related docs as well as more general system-level docs. MRs to
help organize this are appreciated!


To get started:

* `onboarding guide guide <onboarding.rst>`_.


For coding guides see:


* `coding tips <development/coding_tips.rst>`_.
* `coding conventions <development/coding_conventions.rst>`_.
* `testing practices <testing/testing_practices.rst>`_.


For contribution see:

* `contribution instructions <development/contribution_instructions.rst>`_.
* `rebasing procedure <development/rebasing_procedure.rst>`_.
